@@ -34,6 +34,10 @@ class Base(object):
     def set_default_color(cls, color):
         cls.basecolor = images.color_to_rgb(color)
 
+    @classmethod
+    def set_default_style(cls, style):
+        cls.style = style
+
     @classmethod
     def set_default_text_color(cls, color):
         cls.textcolor = images.color_to_rgb(color)
@@ -52,6 +56,7 @@ class Base(object):
         cls.textcolor = (0, 0, 0)
         cls.fontfamily = None
         cls.fontsize = None
+        cls.style = None
 
     def duplicate(self):
         return copy.copy(self)
@@ -199,14 +204,14 @@ class DiagramNode(Element):
         if urlutil.isurl(value) or os.path.isfile(value):
             self.icon = value
         else:
-            msg = "WARNING: icon image not found: %s\n" % value
+            msg = u("WARNING: icon image not found: %s\n") % value
             sys.stderr.write(msg)
 
     def set_background(self, value):
         if urlutil.isurl(value) or os.path.isfile(value):
             self.background = value
         else:
-            msg = "WARNING: background image not found: %s\n" % value
+            msg = u("WARNING: background image not found: %s\n") % value
             sys.stderr.write(msg)
 
     def set_stacked(self, _):
@@ -592,8 +597,8 @@ class Diagram(NodeGroup):
             raise AttributeError(msg)
 
     def set_default_text_color(self, color):
-        msg = "WARNING: default_text_color is obsoleted; " + \
-              "use default_textcolor\n"
+        msg = u("WARNING: default_text_color is obsoleted; "
+                "use default_textcolor\n")
         sys.stderr.write(msg)
         self.set_default_textcolor(color)
 
@@ -607,9 +612,16 @@ class Diagram(NodeGroup):
         color = images.color_to_rgb(color)
         self._DiagramNode.set_default_color(color)
 
+    def set_default_node_style(self, value):
+        if re.search('^(?:none|solid|dotted|dashed|\d+(,\d+)*)$', value, re.I):
+            self._DiagramNode.set_default_style(value)
+        else:
+            msg = "WARNING: unknown %s style: %s\n" % value
+            raise AttributeError(msg)
+
     def set_default_line_color(self, color):
-        msg = "WARNING: default_line_color is obsoleted; " + \
-              "use default_linecolor\n"
+        msg = u("WARNING: default_line_color is obsoleted; "
+                "use default_linecolor\n")
         sys.stderr.write(msg)
         self.set_default_linecolor(color)
 
@@ -655,6 +667,6 @@ class Diagram(NodeGroup):
             raise AttributeError(msg)
 
     def set_fontsize(self, value):
-        msg = "WARNING: fontsize is obsoleted; use default_fontsize\n"
+        msg = u("WARNING: fontsize is obsoleted; use default_fontsize\n")
         sys.stderr.write(msg)
         self.set_default_fontsize(int(value))
