@@ -28,6 +28,7 @@ from blockdiag.imagedraw import base
 from blockdiag.imagedraw.utils import cached
 from blockdiag.imagedraw.utils.ellipse import dots as ellipse_dots
 from blockdiag.utils import urlutil, Box, Size, XY
+from blockdiag.utils.compat import u
 from blockdiag.utils.fontmap import parse_fontpath, FontMap
 from blockdiag.utils.myitertools import istep, stepslice
 
@@ -281,7 +282,13 @@ class ImageDrawExBase(base.ImageDraw):
             size = Size(int(size[0] * font_ratio),
                         int(size[1] * font_ratio))
         else:
-            size = self.draw.textsize(string, font=ttfont)
+            size = ttfont.getsize(string)
+
+            # Avoid offset problem in Pillow (>= 2.2.0)
+            if hasattr(ttfont, 'getoffset'):
+                offset = ttfont.getoffset(string)
+                size = (size[0] + offset[0], size[1] + offset[1])
+
             size = Size(*size)
 
         return size
@@ -305,7 +312,12 @@ class ImageDrawExBase(base.ImageDraw):
                 text_image = image.resize(basesize, Image.ANTIALIAS)
                 self.paste(text_image, xy, text_image)
         else:
-            size = self.draw.textsize(string, font=ttfont)
+            size = ttfont.getsize(string)
+
+            # Avoid offset problem in Pillow (>= 2.2.0)
+            if hasattr(ttfont, 'getoffset'):
+                offset = ttfont.getoffset(string)
+                size = (size[0] + offset[0], size[1] + offset[1])
 
             # Generate mask to support BDF(bitmap font)
             mask = Image.new('1', size)
@@ -354,14 +366,18 @@ class ImageDrawExBase(base.ImageDraw):
     def image(self, box, url):
         if urlutil.isurl(url):
             try:
-                from io import StringIO
+                from io import BytesIO as StringIO
             except ImportError:
                 from cStringIO import StringIO
-            import urllib
             try:
-                url = StringIO(urllib.urlopen(url).read())
+                from urllib.request import urlopen
+            except ImportError:
+                from urllib import urlopen
+
+            try:
+                url = StringIO(urlopen(url).read())
             except:
-                msg = "WARNING: Could not retrieve: %s\n" % url
+                msg = u("WARNING: Could not retrieve: %s\n") % url
                 sys.stderr.write(msg)
                 return
         image = Image.open(url)
