@@ -93,7 +93,8 @@ class TestRstDirectives(unittest.TestCase):
 
         self.assertEqual(1, len(doctree))
         self.assertEqual(directives.blockdiag, type(doctree[0]))
-        self.assertEqual(io.open(filename).read(), doctree[0]['code'])
+        self.assertEqual(io.open(filename, encoding='utf-8-sig').read(),
+                         doctree[0]['code'])
         self.assertEqual(None, doctree[0]['alt'])
         self.assertEqual({}, doctree[0]['options'])
 
@@ -131,6 +132,16 @@ class TestRstDirectives(unittest.TestCase):
         self.assertEqual(0, doctree[0]['uri'].index(self.tmpdir))
         self.assertFalse('target' in doctree[0])
 
+    def test_block_without_braces(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir)
+        text = ".. blockdiag::\n\n   A -> B"
+        doctree = publish_doctree(text)
+        self.assertEqual(1, len(doctree))
+        self.assertEqual(nodes.image, type(doctree[0]))
+        self.assertFalse('alt' in doctree[0])
+        self.assertEqual(0, doctree[0]['uri'].index(self.tmpdir))
+        self.assertFalse('target' in doctree[0])
+
     def test_block_alt(self):
         directives.setup(format='SVG', outputdir=self.tmpdir)
         text = ".. blockdiag::\n   :alt: hello world\n\n   { A -> B }"
