@@ -143,7 +143,13 @@ class BlockdiagDirective(BlockdiagDirectiveBase):
         return directive_options
 
     def node2diagram(self, node):
-        tree = parser.parse_string(node['code'])
+        try:
+            tree = parser.parse_string(node['code'])
+        except:
+            code = 'blockdiag { %s }' % node['code']
+            tree = parser.parse_string(code)
+            node['code'] = code  # replace if suceeded
+
         return ScreenNodeBuilder.build(tree)
 
     def node2image(self, node, diagram):
